@@ -20,7 +20,7 @@
 
 
 module APRS4R
-  APRS4RVersion = [0, 9, 4].join( '.')
+  APRS4RVersion = [0, 9, 5].join( '.')
 
   APRS4RCall = "AP4R0"
 end
@@ -41,9 +41,6 @@ Log4rConfigurator::configure_from_yaml_file( log4r_file)
 require 'aprs4r/APRS4RConfiguration'
 
 require 'aprs4r/SocketManager'
-require 'aprs4r/BeaconManager'
-require 'aprs4r/DigipeaterManager'
-require 'aprs4r/GatewayManager'
 require 'aprs4r/PluginManager'
 
 
@@ -57,19 +54,7 @@ SocketManager.init( configuration)
 
 sleep 2
 
-# start beacon block
-BeaconManager.init( configuration)
-BeaconManager.start()
-
-# start gateway block
-GatewayManager.init( configuration)
-GatewayManager.start()
-
-# start digipeater block
-DigipeaterManager.init( configuration)
-DigipeaterManager.start()
-
-# start generic plugin block
+# start generic plugin manager
 PluginManager.init( configuration)
 PluginManager.start()
 
