@@ -121,12 +121,18 @@ class ISSocket
     @@logger.info( "initServerISSocket()")
 
     software = "\# aprs4r #{APRS4R::APRS4RVersion}"
-    @socket.puts( software)
+    @socket.puts( software + 0x0D.chr)
 
-    line = @socket.gets
-    line.chomp! if line
+    begin
+      Timeout::timeout( 5) do
+        line = @socket.gets
+        line.chomp! if line
 
-    @@logger.debug( "start: #{line}")
+        @@logger.debug( "start: #{line}")
+      end
+    rescue Exception => ex
+      @@logger.warn( "initServerISSocket::ex: #{ex}")
+    end
 
     return
   end
@@ -199,8 +205,6 @@ class ISSocket
           line = @socket.gets
         end
 
-        @@logger.debug( "readData::line: -#{line}-")
-        
         # if nil, an exception is raised (and reinit is started)
         line.chomp!
         @@logger.debug( "readData::line: -#{line}-")
@@ -310,7 +314,7 @@ class ISSocket
     @mutex.synchronize do
       begin
         @@logger.debug( "writeData::data: -#{data}-")
-        @socket.puts( data + '\r')
+        @socket.puts( data + 0x0D.chr)
         @socket.flush
       rescue Exception => ex
         @@logger.warn( "ex: " + ex)
