@@ -19,9 +19,9 @@
 
 require 'Logger'
 
-require 'aprs4r/AX25Socket'
-require 'aprs4r/ISSocket'
-require 'aprs4r/RawSocket'
+# require 'aprs4r/AX25Socket'
+# require 'aprs4r/ISSocket'
+# require 'aprs4r/RawSocket'
 require 'aprs4r/SocketThread'
 
 
@@ -53,33 +53,44 @@ class SocketManager
 
     sockets.each { |name, configuration|
 
-      if configuration.enable 
+      @@logger.debug( "configuration: #{configuration}")
+      
+      name = configuration.name
+      type = configuration.type
+      enable = configuration.enable
 
+      if enable 
         @@logger.debug( "name: #{name}")
+        @@logger.debug( "type: #{type}")
         @@logger.debug( "configuration: #{configuration}")
         
         socket = nil
+        socket_class = "aprs4r" + "/" + type
 
-        # FIXME: dynamic class loading
-        if name =~ /^is\d$/
-          socket = ISSocket.new( configuration)
-        elsif name =~ /^rf\d$/
-          socket = AX25Socket.new( configuration)
+        begin 
+          require socket_class
+
+          socket = eval( "#{type}.new( configuration)")
+          
+        rescue LoadError
+          @@logger.warn( "unable to load socket #{type}")
         end
-        
-        @@logger.debug( "socket: #{socket}")
-        
-        @@threads << Thread.new { 
-          thread = SocketThread.new( socket)
-          thread.run
-        }
-        
-        @@sockets[name] = socket
-        @@listeners[name] = Array.new
-        @@duplicates[name] = Hash.new
 
-        @@recvCount[name] = 0
-        @@sendCount[name] = 0
+        if socket 
+          @@logger.debug( "socket: #{socket}")
+        
+          @@threads << Thread.new { 
+            thread = SocketThread.new( socket)
+            thread.run
+          }
+        
+          @@sockets[name] = socket
+          @@listeners[name] = Array.new
+          @@duplicates[name] = Hash.new
+          
+          @@recvCount[name] = 0
+          @@sendCount[name] = 0
+        end
       end
     }
 
