@@ -139,33 +139,40 @@ class WMRWeatherMessage
     return direction
   end
 
-  def wind_gust_speed
-    speed = 0.0
-
-    if has_wind? && payload.length >= 4
-      speed = high_nibble( payload[3]) * 10.0 + low_nibble( payload[3]) + high_nibble( payload[2]) / 10.0
-    end
-
-    return speed
-  end
-
 
   def wind_avg_speed
     speed = 0.0
 
     if has_wind? && payload.length >= 6
       speed = low_nibble( payload[5]) * 10.0 + high_nibble( payload[4]) + low_nibble( payload[4]) / 10.0
+
+      speed *= 3.6 / 1.852
     end
     
     return speed
   end
 
 
+  def wind_gust_speed
+    speed = 0.0
+
+    if has_wind? && payload.length >= 4
+      speed = high_nibble( payload[3]) * 10.0 + low_nibble( payload[3]) + high_nibble( payload[2]) / 10.0
+      
+      speed *= 3.6 / 1.852
+    end
+
+    return speed
+  end
+
+
   def rain_current
     rain = 0.0
 
     if has_rain? && payload.length >= 3
       rain = low_nibble( payload[2]) * 100.0 + high_nibble( payload[1]) * 10.0 + low_nibble( payload[1])
+
+      rain /= 2.54 * 100.0
     end
 
     return rain
@@ -177,6 +184,8 @@ class WMRWeatherMessage
 
     if has_rain? && payload.length >= 5
       rain = high_nibble( payload[4]) * 1000.0 + low_nibble( payload[4]) * 100.0 + high_nibble( payload[3]) * 10.0 + low_nibble( payload[3]) + high_nibble( payload[2]) / 10.0
+
+      rain /= 2.54 * 100.0
     end
 
     return rain
@@ -188,6 +197,8 @@ class WMRWeatherMessage
 
     if has_rain? && payload.length >= 7
       rain = high_nibble( payload[6]) * 1000.0 + low_nibble( payload[6]) * 100.0 + high_nibble( payload[5]) * 10.0 + low_nibble( payload[5])
+
+      rain /= 2.54 * 100.0
     end
 
     return rain
@@ -203,11 +214,14 @@ class WMRWeatherMessage
       if (payload[2].to_i & 0x80) == 1
         temperature *= -1.0
       end
+
+      temperature = temperature * 9.0 / 5.0 + 32
     end
 
     return temperature
   end
 
+
   def humidity
     humidity = 0.0
 
@@ -218,16 +232,39 @@ class WMRWeatherMessage
     return humidity
   end
 
+
   def dewpoint
     dewpoint = 0.0
     
     if has_baro? && payload.length >= 5
-      humidity = high_nibble( payload[4]) * 10.0 + low_nibble( payload[4])
+      dewpoint = high_nibble( payload[4]) * 10.0 + low_nibble( payload[4])
+
+      dewpoint = dewpoint * 9.0 / 5.0 + 32
     end
     
     return dewpoint
   end
 
+
+  def pressure
+    pressure = 0
+
+    if has_baro? 
+      case type
+      when @@WMR_MESSAGE_TYPE_THERMO_HYGRO_BARO_INDOOR1
+        if payload.length >= 6
+          pressure = payload[5] + 795
+        end
+      when @@WMR_MESSAGE_TYPE_THERMO_HYGRO_BARO_INDOOR2
+        if payload.length >= 7
+          pressure = ((payload[6] & 0x01) << 8) + payload[5] + 600
+        end
+      end
+    end
+
+    return pressure
+  end
+
   def minute
     minute = 0
 
