@@ -194,16 +194,16 @@ class XMLDataPlugin < Plugin
           # start station section
           type = "else"
           type = message.symbol_name if message.has_symbol? && message.symbol_name != ""
+          # @@logger.warn( "symbol: code: #{message.symbol_code} name: #{message.symbol_name}")
           station_open = sprintf( "<station source=\"%s\" destination=\"%s\" path=\"%s\" name=\"%s\">", source, destination, path_list, type)
           file.puts( station_open)
 
           # write position
           position = @positions[source]
-          if position
-            output = "<position lat=\"00.0000\" lng=\"000.0000\"/>"
-            output = sprintf( "<position lat=\"%02.04f\" lng=\"%03.04f\"/>", position.latitude, position.longitude) if position.has_position?
-            file.puts( output)
-          end
+
+          output = "<position lat=\"00.0000\" lng=\"000.0000\"/>"
+          output = sprintf( "<position lat=\"%02.04f\" lng=\"%03.04f\"/>", position.latitude, position.longitude) if position && position.has_position?
+          file.puts( output)
                                 
           # write timestamp
           timestamp = @timestamps[source]
@@ -215,14 +215,14 @@ class XMLDataPlugin < Plugin
           # write comment section
           comment = @comments[source]
           if comment
-            output = sprintf( "<comment>%s</comment>", comment.comment) if comment.has_comment?
+            output = sprintf( "<comment>%s</comment>", escapeHTML( comment.comment)) if comment.has_comment?
             file.puts( output)
           end
 
           # write status section
           status = @states[source]
           if status
-            output = sprintf( "<status>%s</status>", status.status) if status.has_status?
+            output = sprintf( "<status>%s</status>", escapeHTML( status.status)) if status.has_status?
             file.puts( output)
           end
 
@@ -262,4 +262,10 @@ class XMLDataPlugin < Plugin
     end
 
   end
+
+  # escape html symbols (&/><, copied from cgi class)
+  def escapeHTML( value) 
+    return value.gsub(/&/n, '&amp;').gsub(/\"/n, '&quot;').gsub(/>/n, '&gt;').gsub(/</n, '&lt;')
+  end
+
 end
