@@ -22,11 +22,11 @@ require 'aprs4r/PluginConfiguration'
 
 class XMLDataPluginConfiguration < PluginConfiguration
 
-  attr_reader :file, :device
-  attr_writer :file, :device
+  attr_reader :file, :device, :call, :latitude, :longitude
+  attr_writer :file, :device, :call, :latitude, :longitude
 
   def to_yaml_properties
-    %w{ super @file @device}
+    %w{ super @file @device @call @latitude @longitude}
   end
 
 end
